@@ -13,6 +13,7 @@ from pax._src.core import (
     module_and_value,
     parameters_method,
     pure,
+    purecall,
     select_parameters,
     unfreeze_parameters,
     unwrap_mp_policy,
@@ -47,7 +48,7 @@ from pax._src.nn import (
 from pax._src.nn.dropout import dropout
 from pax._src.utils import build_update_fn, grad, scan, value_and_grad
 
-__version__ = "0.5.0"
+__version__ = "0.5.1"
 
 __all__ = (
     "apply_mp_policy",
@@ -88,6 +89,7 @@ __all__ = (
     "ParameterModule",
     "parameters_method",
     "pure",
+    "purecall",
     "RngSeq",
     "scan",
     "seed_rng_key",
