@@ -4,7 +4,8 @@ from .graph_module import GraphModule, InputNode, build_graph_module
 from .mixed_precision import apply_mp_policy, unwrap_mp_policy
 from .module import Module, parameters_method
 from .module_and_value import module_and_value
-from .pure import pure
+from .mutable import mutable
+from .pure import pure, purecall
 from .transforms import (
     enable_eval_mode,
     enable_train_mode,
