@@ -23,7 +23,7 @@ class BaseModule:
     - ``tree_flatten`` converts a module to ``(leaves, treedef)``
     - ``tree_unflatten`` restores the module.
 
-    BaseModule maintains a ``_pytree_attributes`` tuple that lists all subtree attribute names.
+    BaseModule maintains a ``pytree_attributes`` tuple that lists all subtree attribute names.
     """
 
     _pytree_attributes: Tuple[str, ...] = ()
@@ -47,8 +47,8 @@ class BaseModule:
             leaves, _ = jax.tree_flatten(value, is_leaf=is_mod_or_node)
             pytree_cls = (jnp.ndarray, np.ndarray, BaseModule, EmptyNode)
             any_pytree = any(map(is_pytree, leaves))
-            all_pyrtee = all(map(is_pytree, leaves))
-            if any_pytree and all_pyrtee:
+            all_pytree = all(map(is_pytree, leaves))
+            if any_pytree and all_pytree:
                 pytree_attributes.append(name)
             elif any_pytree:
                 mixed_pytree_attributes.append(name)
@@ -136,6 +136,9 @@ class EmptyNode(Tuple):
         del aux, children
         return EmptyNode()
 
+    def __repr__(self) -> str:
+        return "EmptyNode"
+
 
 @jax.tree_util.register_pytree_node_class
 class ValueNode:
@@ -151,3 +154,6 @@ class ValueNode:
     @classmethod
     def tree_unflatten(cls, value, children):
         return ValueNode(value)
+
+    def __repr__(self) -> str:
+        return f"ValueNode({self.value})"
